[Fedora-livecd-list] imgcreate/creator.py imgcreate/live.py

Jeremy Katz katzj at fedoraproject.org
Tue Dec 9 18:36:11 UTC 2008


 imgcreate/creator.py |    4 ++--
 imgcreate/live.py    |    2 +-
 2 files changed, 3 insertions(+), 3 deletions(-)

New commits:
commit c608a60c6c419d1c71ace7dcfa26e7c1b00fa5ab
Author: Jeremy Katz <katzj at redhat.com>
Date:   Tue Dec 9 13:33:50 2008 -0500

    Support live images using an ext4 rootfs

diff --git a/imgcreate/live.py b/imgcreate/live.py
index fb1f917..347d22c 100644
--- a/imgcreate/live.py
+++ b/imgcreate/live.py
@@ -209,7 +209,7 @@ class LiveImageCreatorBase(LoopImageCreator):
 
         f.write('LIVEOS="yes"\n')
         f.write('PROBE="no"\n')
-        f.write('MODULES+="squashfs ext3 ext2 vfat msdos "\n')
+        f.write('MODULES+="squashfs ext4 ext3 ext2 vfat msdos "\n')
         f.write('MODULES+="sr_mod sd_mod ide-cd cdrom "\n')
 
         for module in self.__modules:





More information about the Fedora-livecd-list mailing list
diff --git a/imgcreate/creator.py b/imgcreate/creator.py
index 519735e..5c7f13d 100644
--- a/imgcreate/creator.py
+++ b/imgcreate/creator.py
@@ -865,7 +865,7 @@ class LoopImageCreator(ImageCreator):
     def __get_fstype(self):
         return self.__fstype
     def __set_fstype(self, val):
-        if val != "ext2" and val != "ext3":
+        if val not in ("ext2", "ext3", "ext4"):
             raise CreatorError("Unknown _fstype '%s' supplied" % val)
         self.__fstype = val
     _fstype = property(__get_fstype, __set_fstype)
@@ -874,7 +874,7 @@ class LoopImageCreator(ImageCreator):
     This is the filesystem type used when creating the filesystem image.
     Subclasses may change this if they wish to use something other ext3.
 
     Note, only ext2 and ext3 are currently supported.
 
     Note also, this attribute may only be set before calling mount().
 
@@ -874,7 +874,7 @@ class LoopImageCreator(ImageCreator):
     Subclasses may change this if they wish to use something other ext3.
 
-    Note, only ext2 and ext3 are currently supported.
+    Note, only ext2, ext3, ext4 are currently supported.
 
     Note also, this attribute may only be set before calling mount().